@@ -16,7 +16,6 @@ def process_results(job_dir, json_file):
     :param job_dir: str
     :param json_file: obj
     """
-
     if os.path.exists(json_file):
         with open(json_file, 'r') as datafile:
             try:
@@ -42,9 +41,10 @@ def process_results(job_dir, json_file):
                     for var in obs["metadata"]:
                         data["variables"][var] = {"category": "metadata", "datatype": "<class 'str'>"}
                     # Keep track of all observations variables stored
-                    for othervars in obs["observations"]:
-                        data["variables"][othervars] = {"category": "observations",
-                                                        "datatype": obs["observations"][othervars]["datatype"]}
+                    for sample in obs["observations"]:
+                        for othervars in obs["observations"][sample]:
+                            data["variables"][othervars] = {"category": "observations",
+                                                            "datatype": obs["observations"][sample][othervars]["datatype"]}
 
     # Write out json file with info from all images
     with open(json_file, 'w') as datafile:
