@@ -6,28 +6,27 @@ import numpy as np
 from plantcv.plantcv import params
 from plantcv.plantcv import dilate
 from plantcv.plantcv import outputs
-from plantcv.plantcv import plot_image
-from plantcv.plantcv import print_image
 from plantcv.plantcv import find_objects
+from plantcv.plantcv._debug import _debug
 
 
-def find_tips(skel_img, mask=None):
-    """
+def find_tips(skel_img, mask=None, label="default"):
+    """Find tips in skeletonized image.
     The endpoints algorithm was inspired by Jean-Patrick Pommier: https://gist.github.com/jeanpat/5712699
-    Find tips in skeletonized image.
 
     Inputs:
     skel_img    = Skeletonized image
     mask        = (Optional) binary mask for debugging. If provided, debug image will be overlaid on the mask.
+    label        = optional label parameter, modifies the variable name of observations recorded
 
     Returns:
     tip_img   = Image with just tips, rest 0
 
     :param skel_img: numpy.ndarray
     :param mask: numpy.ndarray
+    :param label: str
     :return tip_img: numpy.ndarray
     """
-
     # In a kernel: 1 values line up with 255s, -1s line up with 0s, and 0s correspond to dont care
     endpoint1 = np.array([[-1, -1, -1],
                           [-1, 1, -1],
@@ -72,22 +71,17 @@ def find_tips(skel_img, mask=None):
     tip_labels = []
     for i, tip in enumerate(tip_objects):
         x, y = tip.ravel()[:2]
-        tip_list.append((int(x), int(y)))
+        coord = (int(x), int(y))
+        tip_list.append(coord)
         tip_labels.append(i)
         cv2.circle(tip_plot, (x, y), params.line_thickness, (0, 255, 0), -1)
 
-    outputs.add_observation(variable='tips', trait='list of tip coordinates identified from a skeleton',
+    outputs.add_observation(sample=label, variable='tips', trait='list of tip coordinates identified from a skeleton',
                             method='plantcv.plantcv.morphology.find_tips', scale='pixels', datatype=list,
                             value=tip_list, label=tip_labels)
 
     # Reset debug mode
     params.debug = debug
-    # Auto-increment device
-    params.device += 1
-
-    if params.debug == 'print':
-        print_image(tip_plot, os.path.join(params.debug_outdir, str(params.device) + '_skeleton_tips.png'))
-    elif params.debug == 'plot':
-        plot_image(tip_plot)
+    _debug(visual=tip_plot, filename=os.path.join(params.debug_outdir, f"{params.device}_skeleton_tips.png"))
 
     return tip_img
