@@ -3,15 +3,15 @@
 import os
 import cv2
 import numpy as np
-from plantcv.plantcv import print_image
-from plantcv.plantcv import plot_image
+from plantcv.plantcv._debug import _debug
 from plantcv.plantcv import fatal_error
 from plantcv.plantcv import params
 
 
 # Create an ROI from a binary mask
 def from_binary_image(img, bin_img):
-    """Create an ROI from a binary image
+    """
+    Create an ROI from a binary image
 
     Inputs:
     img           = An RGB or grayscale image to plot the ROI on.
@@ -26,23 +26,21 @@ def from_binary_image(img, bin_img):
     :return roi_contour: list
     :return roi_hierarchy: numpy.ndarray
     """
-    # Autoincrement the device counter
-    params.device += 1
     # Make sure the input bin_img is binary
     if len(np.unique(bin_img)) != 2:
         fatal_error("Input image is not binary!")
     # Use the binary image to create an ROI contour
     roi_contour, roi_hierarchy = cv2.findContours(np.copy(bin_img), cv2.RETR_TREE, cv2.CHAIN_APPROX_NONE)[-2:]
     # Draw the ROI if requested
-    if params.debug is not None:
-        _draw_roi(img=img, roi_contour=roi_contour)
+    _draw_roi(img=img, roi_contour=roi_contour)
 
     return roi_contour, roi_hierarchy
 
 
 # Create a rectangular ROI
 def rectangle(img, x, y, h, w):
-    """Create a rectangular ROI.
+    """
+    Create a rectangular ROI.
 
     Inputs:
     img           = An RGB or grayscale image to plot the ROI on in debug mode.
@@ -63,9 +61,6 @@ def rectangle(img, x, y, h, w):
     :return roi_contour: list
     :return roi_hierarchy: numpy.ndarray
     """
-    # Autoincrement the device counter
-    params.device += 1
-
     # Get the height and width of the reference image
     height, width = np.shape(img)[:2]
 
@@ -80,8 +75,7 @@ def rectangle(img, x, y, h, w):
     roi_hierarchy = np.array([[[-1, -1, -1, -1]]], dtype=np.int32)
 
     # Draw the ROI if requested
-    if params.debug is not None:
-        _draw_roi(img=img, roi_contour=roi_contour)
+    _draw_roi(img=img, roi_contour=roi_contour)
 
     # Check whether the ROI is correctly bounded inside the image
     if x < 0 or y < 0 or x + w > width or y + h > height:
@@ -92,7 +86,8 @@ def rectangle(img, x, y, h, w):
 
 # Create a circular ROI
 def circle(img, x, y, r):
-    """Create a circular ROI.
+    """
+    Create a circular ROI.
 
     Inputs:
     img           = An RGB or grayscale image to plot the ROI on in debug mode.
@@ -111,9 +106,6 @@ def circle(img, x, y, r):
     :return roi_contour: list
     :return roi_hierarchy: numpy.ndarray
     """
-    # Autoincrement the device counter
-    params.device += 1
-
     # Get the height and width of the reference image
     height, width = np.shape(img)[:2]
 
@@ -126,8 +118,7 @@ def circle(img, x, y, r):
     roi_contour, roi_hierarchy = cv2.findContours(bin_img, cv2.RETR_TREE, cv2.CHAIN_APPROX_NONE)[-2:]
 
     # Draw the ROI if requested
-    if params.debug is not None:
-        _draw_roi(img=img, roi_contour=roi_contour)
+    _draw_roi(img=img, roi_contour=roi_contour)
 
     # Check whether the ROI is correctly bounded inside the image
     if x - r < 0 or x + r > width or y - r < 0 or y + r > height:
@@ -138,7 +129,8 @@ def circle(img, x, y, r):
 
 # Create an elliptical ROI
 def ellipse(img, x, y, r1, r2, angle):
-    """Create an elliptical ROI.
+    """
+    Create an elliptical ROI.
 
     Inputs:
     img           = An RGB or grayscale image to plot the ROI on in debug mode.
@@ -161,9 +153,6 @@ def ellipse(img, x, y, r1, r2, angle):
     :return roi_contour: list
     :return roi_hierarchy: numpy.ndarray
     """
-    # Autoincrement the device counter
-    params.device += 1
-
     # Get the height and width of the reference image
     height, width = np.shape(img)[:2]
 
@@ -176,8 +165,7 @@ def ellipse(img, x, y, r1, r2, angle):
     roi_contour, roi_hierarchy = cv2.findContours(bin_img, cv2.RETR_TREE, cv2.CHAIN_APPROX_NONE)[-2:]
 
     # Draw the ROI if requested
-    if params.debug is not None:
-        _draw_roi(img=img, roi_contour=roi_contour)
+    _draw_roi(img=img, roi_contour=roi_contour)
 
     # Checks ellipse goes outside the image by checking row and column sum of edges
     if (np.sum(bin_img[0, :]) + np.sum(bin_img[-1, :]) + np.sum(bin_img[:, 0]) + np.sum(bin_img[:, -1]) > 0) or \
@@ -189,7 +177,8 @@ def ellipse(img, x, y, r1, r2, angle):
 
 # Draw the ROI on a reference image
 def _draw_roi(img, roi_contour):
-    """Draw an ROI
+    """
+    Draw an ROI
 
     :param img: numpy.ndarray
     :param roi_contour: list
@@ -201,16 +190,13 @@ def _draw_roi(img, roi_contour):
         ref_img = cv2.cvtColor(ref_img, cv2.COLOR_GRAY2BGR)
     # Draw the contour on the reference image
     cv2.drawContours(ref_img, roi_contour, -1, (255, 0, 0), params.line_thickness)
-    if params.debug == "print":
-        # If debug is print, save the image to a file
-        print_image(ref_img, os.path.join(params.debug_outdir, str(params.device) + "_roi.png"))
-    elif params.debug == "plot":
-        # If debug is plot, print to the plotting device
-        plot_image(ref_img)
+    _debug(visual=ref_img,
+           filename=os.path.join(params.debug_outdir, str(params.device) + "_roi.png"))
 
 
 def multi(img, coord, radius, spacing=None, nrows=None, ncols=None):
-    """Create multiple circular ROIs on a single image
+    """
+    Create multiple circular ROIs on a single image
     Inputs
     img           = Input image data.
     coord         = Two-element tuple of the center of the top left object (x,y) or a list of tuples identifying
@@ -233,10 +219,6 @@ def multi(img, coord, radius, spacing=None, nrows=None, ncols=None):
     :param ncols: int
     :return mask: numpy.ndarray
     """
-
-    # Autoincrement the device counter
-    params.device += 1
-
     # Store user debug
     debug = params.debug
 
@@ -276,8 +258,7 @@ def multi(img, coord, radius, spacing=None, nrows=None, ncols=None):
                 circle_img = cv2.circle(bin_img, (x, y), radius, 255, -1)
                 overlap_img = overlap_img + circle_img
                 # Make a list of contours and hierarchies
-                _, rc, rh = cv2.findContours(circle_img, cv2.RETR_EXTERNAL,
-                                             cv2.CHAIN_APPROX_NONE)
+                rc, rh = cv2.findContours(circle_img, cv2.RETR_EXTERNAL, cv2.CHAIN_APPROX_NONE)[-2:]
                 roi_contour.append(rc)
                 roi_hierarchy.append(rh)
 
@@ -299,7 +280,7 @@ def multi(img, coord, radius, spacing=None, nrows=None, ncols=None):
             circle_img = cv2.circle(bin_img, (x, y), radius, 255, -1)
             overlap_img = overlap_img + circle_img
             # Make a list of contours and hierarchies
-            _, rc, rh = cv2.findContours(circle_img, cv2.RETR_EXTERNAL, cv2.CHAIN_APPROX_NONE)
+            rc, rh = cv2.findContours(circle_img, cv2.RETR_EXTERNAL, cv2.CHAIN_APPROX_NONE)[-2:]
             roi_contour.append(rc)
             roi_hierarchy.append(rh)
     else:
@@ -313,21 +294,19 @@ def multi(img, coord, radius, spacing=None, nrows=None, ncols=None):
         print("WARNING: Two or more of the user defined regions of interest overlap! "
               "If you only see one ROI then they may overlap exactly.")
 
+    # Draw the ROIs if requested
+    # Create an array of contours and list of hierarchy for debug image
+    roi_contour1, _ = cv2.findContours(all_roi_img, cv2.RETR_TREE, cv2.CHAIN_APPROX_NONE)[-2:]
     # Reset debug
     params.debug = debug
-
-    # Draw the ROIs if requested
-    if params.debug is not None:
-        # Create an array of contours and list of hierarchy for debug image
-        roi_contour1, roi_hierarchy1 = cv2.findContours(all_roi_img, cv2.RETR_TREE,
-                                                        cv2.CHAIN_APPROX_NONE)[-2:]
-        _draw_roi(img=img, roi_contour=roi_contour1)
+    _draw_roi(img=img, roi_contour=roi_contour1)
 
     return roi_contour, roi_hierarchy
 
 
 def custom(img, vertices):
-    """Create an custom polygon ROI.
+    """
+    Create an custom polygon ROI.
 
         Inputs:
         img           = An RGB or grayscale image to plot the ROI on in debug mode.
@@ -341,18 +320,15 @@ def custom(img, vertices):
         :param vertices: list
         :return roi_contour: list
         :return roi_hierarchy: numpy.ndarray
-        """
-    # Autoincrement the device counter
-    params.device += 1
-
+    """
     # Get the height and width of the reference image
     height, width = np.shape(img)[:2]
 
     roi_contour = [np.array(vertices, dtype=np.int32)]
     roi_hierarchy = np.array([[[-1, -1, -1, -1]]], dtype=np.int32)
 
-    if params.debug is not None:
-        _draw_roi(img=img, roi_contour=roi_contour)
+    # Draw the ROIs if requested
+    _draw_roi(img=img, roi_contour=roi_contour)
 
     # Check that the ROI doesn't go off the screen
     for i in vertices:
