@@ -6,5 +6,6 @@ from plantcv.plantcv.threshold.threshold_methods import triangle
 from plantcv.plantcv.threshold.threshold_methods import texture
 from plantcv.plantcv.threshold.threshold_methods import custom_range
 from plantcv.plantcv.threshold.threshold_methods import saturation
+from plantcv.plantcv.threshold.threshold_methods import mask_bad
 
-__all__ = ["binary", "gaussian", "mean", "otsu", "triangle", "texture", "custom_range", "saturation"]
+__all__ = ["binary", "gaussian", "mean", "otsu", "triangle", "texture", "custom_range", "saturation", "mask_bad"]
